@@ -80,12 +80,19 @@ type Format struct {
 
 // ER is er setting
 type ER struct {
-	Skip     bool   `yaml:"skip,omitempty"`
-	Format   string `yaml:"format,omitempty"`
-	Comment  bool   `yaml:"comment,omitempty"`
-	HideDef  bool   `yaml:"hideDef,omitempty"`
-	Distance *int   `yaml:"distance,omitempty"`
-	Font     string `yaml:"font,omitempty"`
+	Skip            bool             `yaml:"skip,omitempty"`
+	Format          string           `yaml:"format,omitempty"`
+	Comment         bool             `yaml:"comment,omitempty"`
+	HideDef         bool             `yaml:"hideDef,omitempty"`
+	ShowColumnTypes *ShowColumnTypes `yaml:"showColumnTypes,omitempty"`
+	Distance        *int             `yaml:"distance,omitempty"`
+	Font            string           `yaml:"font,omitempty"`
+}
+
+// ShowColumnTypes is show column setting for ER diagram
+type ShowColumnTypes struct {
+	Related bool `yaml:"related,omitempty"`
+	Primary bool `yaml:"primary,omitempty"`
 }
 
 // AdditionalRelation is the struct for table relation from yaml
@@ -388,17 +395,14 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 	if err := detectPKFK(s); err != nil {
 		return err
 	}
-	err := c.MergeAdditionalData(s)
-	if err != nil {
+	if err := c.MergeAdditionalData(s); err != nil {
 		return err
 	}
-	err = c.FilterTables(s)
-	if err != nil {
+	if err := c.FilterTables(s); err != nil {
 		return err
 	}
 	if c.Format.Sort {
-		err = s.Sort()
-		if err != nil {
+		if err := s.Sort(); err != nil {
 			return err
 		}
 	}
@@ -413,6 +417,9 @@ func (c *Config) ModifySchema(s *schema.Schema) error {
 	if err := detectCardinality(s); err != nil {
 		return err
 	}
+	if err := c.detectShowColumnsForER(s); err != nil {
+		return err
+	}
 	return nil
 }
 
@@ -566,6 +573,38 @@ func (c *Config) NeedToGenerateERImages() bool {
 	return true
 }
 
+func (c *Config) detectShowColumnsForER(s *schema.Schema) error {
+	if c.ER.ShowColumnTypes == nil {
+		return nil
+	}
+
+	if !c.ER.ShowColumnTypes.Related && !c.ER.ShowColumnTypes.Primary {
+		return errors.New("er.showColumnTypes: must be true at least one")
+	}
+
+	for _, t := range s.Tables {
+		for _, cc := range t.Columns {
+			if c.ER.ShowColumnTypes.Related && (cc.ChildRelations != nil || cc.ParentRelations != nil) {
+				// related
+				cc.HideForER = false
+			} else if c.ER.ShowColumnTypes.Primary && cc.PK {
+				// primary
+				cc.HideForER = false
+			} else {
+				cc.HideForER = true
+				for _, r := range cc.ChildRelations {
+					r.HideForER = true
+				}
+				for _, r := range cc.ParentRelations {
+					r.HideForER = true
+				}
+			}
+		}
+	}
+
+	return nil
+}
+
 func mergeAdditionalRelations(s *schema.Schema, relations []AdditionalRelation) error {
 	for _, r := range relations {
 		relation := &schema.Relation{
