@@ -13,11 +13,13 @@ import (
 
 func TestOutputSchema(t *testing.T) {
 	tests := []struct {
-		hideDef  bool
-		wantFile string
+		hideDef         bool
+		showColumnTypes *config.ShowColumnTypes
+		wantFile        string
 	}{
-		{false, "dot_test_schema.dot"},
-		{true, "dot_test_schema.dot.hidedef"},
+		{false, nil, "dot_test_schema.dot"},
+		{true, nil, "dot_test_schema.dot.hidedef"},
+		{false, &config.ShowColumnTypes{Related: true}, "dot_test_schema.dot.hide_not_related_column"},
 	}
 	for _, tt := range tests {
 		t.Run(tt.wantFile, func(t *testing.T) {
@@ -26,10 +28,11 @@ func TestOutputSchema(t *testing.T) {
 			if err != nil {
 				t.Error(err)
 			}
-			c.ER.HideDef = tt.hideDef
 			if err := c.LoadConfigFile(filepath.Join(testdataDir(), "out_test_tbls.yml")); err != nil {
 				t.Error(err)
 			}
+			c.ER.HideDef = tt.hideDef
+			c.ER.ShowColumnTypes = tt.showColumnTypes
 			if err := c.ModifySchema(s); err != nil {
 				t.Error(err)
 			}
